@@ -1,6 +1,6 @@
 
 from django.apps import AppConfig
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 def setup_settings(settings, is_prod, **kwargs):
